@@ -11,6 +11,7 @@ import logging
 import sys
 
 import django
+import django.db.models
 from django.conf import settings
 from django.http import HttpResponse
 
@@ -24,6 +25,7 @@ from .attributes import (
     Aggregate,
     ConsumerAttribute,
     DeferrableEndpointTask,
+    DeferrableGenericEndpointTask,
     EndpointAttribute,
     EndpointTask,
     RawRequestObjectProperty,
@@ -228,7 +230,9 @@ class EndpointBinder:
 
             resource = self.bound_endpoint.resource
 
-            if hasattr(resource, "is_dirty"):
+            if isinstance(resource, django.db.models.Model) and hasattr(
+                resource, "is_dirty"
+            ):
                 if resource and resource.is_dirty(check_relationship=True):
                     update_dirty(resource)
 
@@ -255,7 +259,9 @@ class EndpointBinder:
                     update_dirty(resource)
                 raise
 
-            if hasattr(resource, "is_dirty"):
+            if isinstance(resource, django.db.models.Model) and hasattr(
+                resource, "is_dirty"
+            ):
                 if resource and resource.is_dirty(check_relationship=True):
                     update_dirty(resource)
 
@@ -442,8 +448,9 @@ class BehavioralEndpointDefinitionRouter:
                 "Processing request with handler %s",
                 bound_endpoint.bound_endpoint.__class__.__name__,
             )
-            return bound_endpoint.get_response()
-
+            result = bound_endpoint.get_response()
+            bound_endpoint.bound_endpoint.finalize()
+            return result
         except errors.ApiError:
             raise
         except Exception as e:  # pragma: nocover
@@ -607,6 +614,13 @@ class BaseEndpointDefinition(metaclass=EndpointDefinitionMeta):
         """
         return self.resource
 
+    def finalize(self):
+        """
+        Called immediately before a response is returned.  Override this method in an
+        Endpoint Definition to perform any clean-up not handled automatically by the framework.
+        """
+        pass
+
     @classmethod
     def get_endpoint_attributes(cls):
         """Returns a list of endpoint attributes
@@ -989,6 +1003,7 @@ class ResourceUpdateEndpointDefinition(ResourceEndpointDefinition):
 
 task = EndpointTask
 deferrable_task = DeferrableEndpointTask
+deferrable_generic_task = DeferrableGenericEndpointTask
 request_attribute = RequestAttribute
 consumer_attribute = ConsumerAttribute
 field = RequestField
